/* Copyright (C) 2023 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Volker Friese [committer] */

#include "DigiEventQa.h"

using std::string;
using std::vector;

namespace cbm::algo::qa
{

  // ---   Execution   --------------------------------------------------------
  DigiEventQaData DigiEventQa::operator()(const vector<CbmDigiEvent>& events, const DigiEventQaConfig& config) const
  {

    // --- Instantiate return object
    DigiEventQaData result;
    for (const auto& entry : config.fData) {
      ECbmModuleId subsystem = entry.first;
      string hist_name       = "digi_time_" + ToString(subsystem);
      auto& detConfig        = config.fData.at(subsystem);
      result.fDigiTimeHistos.try_emplace(subsystem, detConfig.fNumBins, detConfig.fMinValue, detConfig.fMaxValue,
                                         hist_name);
    }

    // --- Event loop. Fill histograms.
    for (const auto& event : events)
      for (auto& subsystem : config.fData)
        QaDigiTimeInEvent(event, subsystem.first, result.fDigiTimeHistos.at(subsystem.first));
    result.fNumEvents = events.size();

    return result;
  }
  // --------------------------------------------------------------------------


  // ---  QA: digi time within event   ----------------------------------------
  void DigiEventQa::QaDigiTimeInEvent(const CbmDigiEvent& event, ECbmModuleId system, Histo1D& histo) const
  {
    switch (system) {
      case ECbmModuleId::kT0: FillDeltaT<CbmBmonDigi>(event.fData.fT0.fDigis, event.fTime, histo); break;
      case ECbmModuleId::kSts: FillDeltaT<CbmStsDigi>(event.fData.fSts.fDigis, event.fTime, histo); break;
      case ECbmModuleId::kMuch: FillDeltaT<CbmMuchDigi>(event.fData.fMuch.fDigis, event.fTime, histo); break;
      case ECbmModuleId::kRich: FillDeltaT<CbmRichDigi>(event.fData.fRich.fDigis, event.fTime, histo); break;
      case ECbmModuleId::kTrd: FillDeltaT<CbmTrdDigi>(event.fData.fTrd.fDigis, event.fTime, histo); break;
      case ECbmModuleId::kTrd2d: FillDeltaT<CbmTrdDigi>(event.fData.fTrd2d.fDigis, event.fTime, histo); break;
      case ECbmModuleId::kTof: FillDeltaT<CbmTofDigi>(event.fData.fTof.fDigis, event.fTime, histo); break;
      case ECbmModuleId::kPsd: FillDeltaT<CbmPsdDigi>(event.fData.fPsd.fDigis, event.fTime, histo); break;
      default: throw std::runtime_error("DigiEventQa: Invalid system Id " + ToString(system));
    }
  }
  // --------------------------------------------------------------------------


} /* namespace cbm::algo::qa */
